@@ -1000,6 +1000,104 @@ void KDirListerTest::testRedirection()
 
 }
 
+void KDirListerTest::testWatchingAfterCopyJob() // #331582
+{
+    m_items.clear();
+
+    KTempDir newDir;
+    const QString path = newDir.name();
+
+    // List and watch an empty dir
+    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    m_dirLister.openUrl(KUrl(path));
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QVERIFY(m_items.isEmpty());
+
+    // Create three subfolders.
+    QVERIFY(QDir().mkdir(path + "New Folder"));
+    QVERIFY(QDir().mkdir(path + "New Folder 1"));
+    QVERIFY(QDir().mkdir(path + "New Folder 2"));
+
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QCOMPARE(m_items.count(), 3);
+
+    // Create a new file and verify that the dir lister notices it.
+    m_items.clear();
+    createTestFile(path + "a");
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QCOMPARE(m_items.count(), 1);
+
+    // Rename one of the subfolders.
+    const QString oldPath = path + "New Folder 1";
+    const QString newPath = path + "New Folder 1a";
+
+    // NOTE: The following two lines are required to trigger the bug!
+    KIO::Job* job = KIO::moveAs(KUrl(oldPath), KUrl(newPath), KIO::HideProgressInfo);
+    job->exec();
+
+    // Now try to create a second new file in and verify that the
+    // dir lister notices it.
+    m_items.clear();
+    createTestFile(path + "b");
+
+    int numTries = 0;
+    // Give time for KDirWatch to notify us
+    // This should end up in "KDirListerCache::slotFileDirty"
+    while (m_items.isEmpty()) {
+        QVERIFY(++numTries < 10);
+        QTest::qWait(200);
+    }
+    QCOMPARE(m_items.count(), 1);
+
+    newDir.unlink();
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(clear()), 1000));
+}
+
+void KDirListerTest::testRemoveWatchedDirectory()
+{
+    m_items.clear();
+
+    KTempDir newDir;
+    const QString path = newDir.name();
+
+    // List and watch an empty dir
+    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    m_dirLister.openUrl(KUrl(path));
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QVERIFY(m_items.isEmpty());
+
+    // Create a subfolder.
+    const QString subDirPath = path + "abc";
+    QVERIFY(QDir().mkdir(subDirPath));
+
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QCOMPARE(m_items.count(), 1);
+    const KFileItem item = m_items.at(0);
+
+    // Watch the subfolder for changes, independently.
+    // This is what triggers the bug.
+    // (Technically, this could become a KDirWatch unittest, but if one day we use QFSW, good to have the tests here)
+    KDirWatch watcher;
+    watcher.addDir(subDirPath);
+
+    // Remove the subfolder.
+    m_items.clear();
+    QVERIFY(QDir().rmdir(path + "abc"));
+
+    // This should trigger an update.
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QCOMPARE(m_items.count(), 0);
+    QCOMPARE(m_dirLister.spyItemsDeleted.count(), 1);
+    const KFileItem deletedItem = m_dirLister.spyItemsDeleted.at(0).at(0).value<KFileItemList>().at(0);
+    QCOMPARE(item, deletedItem);
+}
+
 void KDirListerTest::enterLoop(int exitCount)
 {
     //qDebug("enterLoop");
