@@ -34,6 +34,10 @@ private Q_SLOTS:
     void testToSparql_data();
     void testToSparql();
     void testOptimization();
+    void testLogicalOperators();
+    void testComparison_data();
+    void testComparison();
+    void testTermFromProperty();
 };
 
 #endif
